===========
Haralyzer_3
===========

.. image:: https://github.com/Cyb3r-Jak3/haralyzer_3/workflows/Python%20Checking/badge.svg?branch=master
    :target: https://github.com/Cyb3r-Jak3/haralyzer_3/actions?query=branch%3Amaster+workflow%3A%22Python+Checking%22
    :alt: Build status

.. image:: https://coveralls.io/repos/github/Cyb3r-Jak3/haralyzer_3/badge.svg?branch=master
    :target: https://coveralls.io/github/Cyb3r-Jak3/haralyzer_3?branch=master
    :alt: Coverage status

.. image:: https://readthedocs.org/projects/haralyzer-3/badge/?version=latest
    :target: https://haralyzer-3.readthedocs.io/en/latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Python Black Code Style

A Python 3 Framework For Using HAR Files To Analyze Web Pages.

This is a fork of https://github.com/mrname/haralyzer but only supports Python 3

To learn more about how to this this project, check out the documentation `here <https://haralyzer-3.readthedocs.io/>`_